from _typeshed import Incomplete

class PlanGateway:
    gateway: Incomplete
    config: Incomplete
    def __init__(self, gateway) -> None: ...
    def all(self): ...
    def create(self, params=None): ...
    def find(self, plan_id): ...
    def update(self, plan_id, params=None): ...
