from _typeshed import Incomplete

class Store:
    program: Incomplete
    exe: Incomplete
    environment: Incomplete
    def __init__(self, program, environment=None) -> None: ...
    def get(self, server): ...
    def store(self, server, username, secret): ...
    def erase(self, server) -> None: ...
    def list(self): ...
