from _typeshed import Incomplete
from collections.abc import Callable

def check_resource(resource_name: str): ...
def minimum_version(version: str): ...
def update_headers(f: Callable[..., Incomplete]): ...
